#include <QtGui>

#include <mbarcode-qt/plugininterfaces.h>
#include <mbarcode-qt/pluginaction.h>
#include <mbarcode-qt/maemobarcodewindow.h>

#include "qrplugin.h"
#include "qrsink.h"

QSet<PluginAction*> QrPlugin::getPluginActions() {
    QSet<PluginAction*> newList;
    newList.insert(sink);
    return newList;
}

void QrPlugin::initInterface(QWidget *parent) {
    sink = new QrSink(this);
    connect(parent, SIGNAL(barcodeAnalysedSignal(QString,QString)),
            sink, SLOT(barcodeAnalysed(QString,QString)));
}

//QString TestPlugin::getInterfaceName() const {
//    return "Test plugin";
//}
Q_EXPORT_PLUGIN2(mbqt_qrplugin, QrPlugin)
